==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/s3control/kotlin/inputs/StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3control.kotlin.inputs

import com.pulumi.aws.s3control.inputs.StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property enabled Whether detailed status code metrics are enabled.
 */
public data class
StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs(
    public val enabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.s3control.inputs.StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs> {
    override fun toJava():
        com.pulumi.aws.s3control.inputs.StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs =
        com.pulumi.aws.s3control.inputs.StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs].
 */
@PulumiTagMarker
public class
StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgsBuilder
internal constructor() {
    private var enabled: Output<Boolean>? = null

    /**
     * @param value Whether detailed status code metrics are enabled.
     */
    @JvmName("mvhffdyhlosdehej")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Whether detailed status code metrics are enabled.
     */
    @JvmName("skmwmriljxoniibi")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    internal fun build():
        StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs =
        StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs(
            enabled = enabled,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/s3control/kotlin/inputs/StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3control.kotlin.inputs

import com.pulumi.aws.s3control.inputs.StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property enabled Whether detailed status code metrics are enabled.
 */
public data class
StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs(
    public val enabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.s3control.inputs.StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs> {
    override fun toJava(): com.pulumi.aws.s3control.inputs.StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs =
        com.pulumi.aws.s3control.inputs.StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs].
 */
@PulumiTagMarker
public class
StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgsBuilder
internal constructor() {
    private var enabled: Output<Boolean>? = null

    /**
     * @param value Whether detailed status code metrics are enabled.
     */
    @JvmName("smmxwmmqruhhlmif")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Whether detailed status code metrics are enabled.
     */
    @JvmName("upiflpiprgnwyqqy")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    internal fun build(): StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs =
        StorageLensConfigurationStorageLensConfigurationAccountLevelDetailedStatusCodeMetricsArgs(
            enabled = enabled,
        )
}
